@@ -21,7 +21,8 @@ class UserRoom_Recorder_Handler:
     def create_recorder(self, username, recorder_name = None):
         create_recorder = {
             "username": username,
-            "recorder_name": recorder_name
+            "recorder_name": recorder_name, 
+            "unlimited": "true"
         }
         response = self._recorder_api.create_recorder(create_recorder)
         
